==> pwf-jquery-compat-0.4.2.tgz: package/lib/jquery-compat.js <==
(function()
{
	var
		mod_name = 'jquery',
		mod_initialized = false,
		jq = $.noConflict(true);


	/**
	 * Create new jQuery instance with an element
	 *
	 * @param string tag   Tag name
	 * @param string cname CSS class name
	 * @return jQuery instance
	 */
	jq.el = function(tag, cname)
	{
		var tag = pwf.jquery('<' + tag + '/>');

		if (typeof cname != 'undefined') {
			tag.addClass(cname);
		}

		return tag
	};


	/**
	 * Static helper - create div with less code
	 *
	 * @param string cname
	 * @return jQuery div instance
	 */
	jq.div = function(cname)
	{
		return this.el('div', cname);
	};


	/**
	 * Static helper - create span with less code
	 *
	 * @param string cname
	 * @return jQuery span instance
	 */
	jq.span = function(cname)
	{
		return this.el('span', cname);
	};


	/**
	 * Static helper - create icon with less code
	 *
	 * @param string name
	 * @param string size
	 * @return jQuery icon instance
	 */
	jq.icon = function(name, size)
	{
		var
			size = typeof size == 'undefined' || size === null ? ['16', '16']:size.split('x'),
			w = typeof size[0] == 'undefined' ? null:parseInt(size[0]),
			h = typeof size[1] == 'undefined' ? null:parseInt(size[1]),
			icon = jq.span('icon icon-' + w + 'x' + h + ' icon-' + name.replace(/\//g, '-'));

		if (w !== null) icon.css('width', w);
		if (h !== null) icon.css('height', h);

		return icon;
	};


	/**
	 * Strip HTML tags and return plain text
	 *
	 * @param mixed text
	 * @return string
	 */
	jq.strip_tags = function(text)
	{
		return pwf.jquery('<div/>').html(text).text();
	};


	/**
	 * Fill element with els
	 *
	 * @param Array  list_els List of div elements
	 * @param string tag      Tagname for new els
	 * @param string prefix   Prefix div cnames
	 * @return same jQuery instance
	 */
	jq.fn.create_els = function(list_els, tag, prefix)
	{
		var prefix = typeof prefix == 'string' ? prefix + '-':'';

		for (var i = 0; i < list_els.length; i++) {
			var el = jq.el(tag, prefix + list_els[i]);

			this[list_els[i]] = el;
			this.append(el);
		}

		return this;
	};


	/**
	 * Fill element with divs
	 *
	 * @param Array  list_els List of div elements
	 * @param string prefix   Prefix div cnames
	 * @return same jQuery instance
	 */
	jq.fn.create_divs = function(list_els, prefix)
	{
		return this.create_els(list_els, 'div', prefix);
	};


	/**
	 * Is this element located and visible inside browser window? Return true if
	 * so.
	 *
	 * @return bool
	 */
	jq.fn.in_viewport = function()
	{
		if (this.outerWidth() === 0 || this.outerHeight() === 0) {
			return false;
		}

		var
			height = document.documentElement.clientHeight,
			rects = this[0].getClientRects();

		for (var i = 0, l = rects.length; i < l; i++) {
			var
				r = rects[i],
				in_viewport = r.top > 0 ? r.top <= height:(r.bottom > 0 && r.bottom <= height);

			if (in_viewport) return true;
		}

		return false;
	};


	/**
	 * Is first element of this jQuery set attached to the document? Returns true
	 * if so.
	 *
	 * @return bool
	 */
	jq.fn.is_attached = function()
	{
		return pwf.jquery(this).first().parents(':last').is('html');
	};


	/**
	 * Init function that is called when jQuery is ready (domready event)
	 *
	 * @param function call_upd
	 * @return void
	 */
	jq.init = function(call_upd)
	{
		pwf[mod_name](function(call_upd, module) {
			return function() {
				mod_initialized = true;
				call_upd(mod_name, true);
			};
		}(call_upd, this));

		return mod_initialized;
	};


	if (typeof pwf == 'object') {
		/** Remove jQuery from global scope, so its' less obtrusive */
		pwf.register(mod_name, jq, false);
		pwf.strip_tags = pwf.jquery.strip_tags;
	}


	if (typeof module != 'undefined') {
		module.exports = jq;
	}
}());

==> pwf-jquery-compat-0.5.2.tgz: package/lib/jquery-compat.js <==
(function()
{
	var
		mod_name = 'jquery',
		mod_initialized = false,
		jq = $.noConflict();

	// If there was no previous versions of jQuery, put it back to global scope
	if (typeof $ == 'undefined') {
		$ = jq;
	}

	/**
	 * Create new jQuery instance with an element
	 *
	 * @param string tag   Tag name
	 * @param string cname CSS class name
	 * @return jQuery instance
	 */
	jq.el = function(tag, cname)
	{
		var tag = pwf.jquery('<' + tag + '/>');

		if (typeof cname != 'undefined') {
			tag.addClass(cname);
		}

		return tag
	};


	/**
	 * Static helper - create div with less code
	 *
	 * @param string cname
	 * @return jQuery div instance
	 */
	jq.div = function(cname)
	{
		return this.el('div', cname);
	};


	/**
	 * Static helper - create span with less code
	 *
	 * @param string cname
	 * @return jQuery span instance
	 */
	jq.span = function(cname)
	{
		return this.el('span', cname);
	};


	/**
	 * Static helper - create icon with less code
	 *
	 * @param string name
	 * @param string size
	 * @return jQuery icon instance
	 */
	jq.icon = function(name, size)
	{
		var
			size = typeof size == 'undefined' || size === null ? ['16', '16']:size.split('x'),
			w = typeof size[0] == 'undefined' ? null:parseInt(size[0]),
			h = typeof size[1] == 'undefined' ? null:parseInt(size[1]),
			icon = jq.span('icon icon-' + w + 'x' + h + ' icon-' + name.replace(/\//g, '-'));

		if (w !== null) icon.css('width', w);
		if (h !== null) icon.css('height', h);

		return icon;
	};


	/**
	 * Strip HTML tags and return plain text
	 *
	 * @param mixed text
	 * @return string
	 */
	jq.strip_tags = function(text)
	{
		return pwf.jquery('<div/>').html(text).text();
	};


	/**
	 * Fill element with els
	 *
	 * @param Array  list_els List of div elements
	 * @param string tag      Tagname for new els
	 * @param string prefix   Prefix div cnames
	 * @return same jQuery instance
	 */
	jq.fn.create_els = function(list_els, tag, prefix)
	{
		var prefix = typeof prefix == 'string' ? prefix + '-':'';

		for (var i = 0; i < list_els.length; i++) {
			var el = jq.el(tag, prefix + list_els[i]);

			this[list_els[i]] = el;
			this.append(el);
		}

		return this;
	};


	/**
	 * Fill element with divs
	 *
	 * @param Array  list_els List of div elements
	 * @param string prefix   Prefix div cnames
	 * @return same jQuery instance
	 */
	jq.fn.create_divs = function(list_els, prefix)
	{
		return this.create_els(list_els, 'div', prefix);
	};


	/**
	 * Is this element located and visible inside browser window? Return true if
	 * so.
	 *
	 * @return bool
	 */
	jq.fn.in_viewport = function()
	{
		if (this.outerWidth() === 0 || this.outerHeight() === 0) {
			return false;
		}

		var
			height = document.documentElement.clientHeight,
			rects = this[0].getClientRects();

		for (var i = 0, l = rects.length; i < l; i++) {
			var
				r = rects[i],
				in_viewport = r.top > 0 ? r.top <= height:(r.bottom > 0 && r.bottom <= height);

			if (in_viewport) return true;
		}

		return false;
	};


	/**
	 * Is first element of this jQuery set attached to the document? Returns true
	 * if so.
	 *
	 * @return bool
	 */
	jq.fn.is_attached = function()
	{
		return pwf.jquery(this).first().parents(':last').is('html');
	};


	/**
	 * Init function that is called when jQuery is ready (domready event)
	 *
	 * @param function call_upd
	 * @return void
	 */
	jq.init = function(call_upd)
	{
		pwf[mod_name](function(call_upd, module) {
			return function() {
				mod_initialized = true;
				call_upd(mod_name, true);
			};
		}(call_upd, this));

		return mod_initialized;
	};


	if (typeof pwf == 'object') {
		/** Remove jQuery from global scope, so its' less obtrusive */
		pwf.register(mod_name, jq, false);
		pwf.strip_tags = pwf.jquery.strip_tags;
	}


	if (typeof module != 'undefined') {
		module.exports = jq;
	}
}());
